
%-------------------------------------------------------------------------
%Input file of VolcFLow used for the simulation of the lava dome
%emplacement. Fig. 8a of the paper : 
%Growth and collapses of the 2018-2019 lava dome of Merapi volcano.
%Kelfoun et al., Bull. Volcanol, 2020
%-------------------------------------------------------------------------

%load the summit topoggraphy
%If you want to use the mat-file (faster)
load('ESM5b_DEM_2018.mat') 
%space step
dx_horiz = x(2)-x(1);
dy_horiz = -y(2)+y(1);
[nrow, ncol]=size(z);

% %If you want to use the ASCII DEM
% fid = fopen('ESM5b_DEM_2018.grd'); 
% code = fscanf(fid,'%c',4);
% ncol = fscanf(fid,'%f',1);
% nrow = fscanf(fid,'%f',1);
% xmin = fscanf(fid,'%f',1);
% xmax = fscanf(fid,'%f',1);
% ymin = fscanf(fid,'%f',1);
% ymax = fscanf(fid,'%f',1);
% zmin = fscanf(fid,'%f',1);
% zmax = fscanf(fid,'%f',1);
% zL   = fscanf(fid,'%f', inf);
% z = (reshape(zL, ncol, nrow))';
% fclose(fid);
% dx_horiz = (xmax-xmin)/(ncol-1);
% dy_horiz = (ymax-ymin)/(nrow-1);
% x = [xmin+dx_horiz/2:dx_horiz:xmin+ncol*dx_horiz-dx_horiz/2];
% y = [ymin+nrow*dy_horiz-dy_horiz/2 : -dy_horiz : ymin+dy_horiz/2];
% 


%location of the vent
hsource = double(imread('ESM5b_vent_location.tif'));
hsource = (255-hsource)/255;

%Parameters of the simulation
dt=200;                 %time step of the simulation in seconds
dtplot = 3600*12;       %time step of plots
tmax = 3600*24*15*2;    %duration of the calculation (in s)
tstep_adjust = 0;       %no automatic adaptation of the time step
                        %(recommended for very viscous flows)

g = 9.79;               %gravity (m/s-2)

%Rheological parameters (viscous flow = just viscosity is defined)
rho       = 2300;  %density
delta_int = 0;
delta_bed = 0; 
cohesion  = 0;    
coef_u2   = 0;
viscosity = 5e10;  %viscosity

%Source and boundary conditions
source = 'h=h+hsource/sum(sum(hsource.*S))*( 4000-  20   /3*t/(3600*24) )/(3600*24)*dt;  ';
bound_cond = 'h2(:,1)=0; h2(:,ncol)=0; h2(1,:)=0; h2(nrow,:)=0; u_xx(:,1)=0; u_xx(:,ncol-1)=0; u_yy(1,:)=0; u_yy(nrow-1,:)=0;';

%output
representation = 'ESM5b_repr_dome_2018; set(gcf, ''color'', ''w'');';
f_avi  = 'test.avi';  %be careful, this file will be deleted
f_data = 'test.dat';  %be careful, this file will be deleted
erase_dat = 1;

%internal boudaries 
indCx = []; 
indCy = []; 

%null initial thickness
h=z*0;

%null initial velocities
u_xx = z(1:nrow, 1:ncol-1)*0;
u_xy = z(1:nrow, 1:ncol-1)*0;
u_yy = z(1:nrow-1, 1:ncol)*0;
u_yx = z(1:nrow-1, 1:ncol)*0;





